##  Getting Insights from Reports
Once you have gathered the data, generate reports to gain insights into your application portfolio. This allows you to identify where new AI technologies are already in use and where there are opportunities for improvement and increased efficiency.
For example:
  * Using an application landscape report, you can easily identify which key business capabilities are at risk arising from AI usage or which business capabilities can leverage AI better. To do so, in the application landscape report clustered by business capabilities, you can apply AI Risk or AI Potential as a view. To learn how to use reports, see [Using Reports](https://help.sap.com/docs/leanix/ea/using-reports?locale=en-US&state=PRODUCTION&version=CLOUD).


**Tip**
Apply the AI Available filter from the filter bar to display only those applications that use AI capabilities.
**Note**
To avoid overwhelming users with too many view attributes and to keep the interface lean, many fields are hidden by default in the View drop-down menu in reports. In the meta model configuration, you can choose to include or exclude attributes based on your needs. To learn more, see [Showing Fields in Views](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759fb817a44101492ded5b080b9f10c__showing_fields_in_views).
  * You can also use a business capability landscape report to get a consolidated view to identify and prioritize business capabilities with high potential for AI adoption.
![Using Business Capability Landscape Report to Identify AI Potential](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756caed7a4410149e81fb7028a60d20_LowRes.png)
Using Business Capability Landscape Report to Identify AI Potential
  * With the IT component matrix report, you can assess which AI algorithms and large language models (LLMs) are supporting which applications. To do so, in the IT component matrix report settings, select Application for one of the axes and apply the necessary view for your analysis.
  * Using the technology radar report, you can gain insights into your AI governance and adoption status. From the radar report settings, choose AI Radar Classification for the sector category. To learn more about radar reports, see [Radar Report](https://help.sap.com/docs/leanix/ea/radar-report?locale=en-US&state=PRODUCTION&version=CLOUD "A Radar report offers a visual representation of fact sheets categorized in rings and sectors. It aids in understanding an organization's tech landscape and evaluate technology standards.").
